@@ -78,20 +78,20 @@ static inline bool callSetOutputDevice(AudioOutputPrivate *const d, const AudioO
 AudioOutput::AudioOutput(Phonon::Category category, QObject *parent)
     : AbstractAudioOutput(*new AudioOutputPrivate, parent)
 {
-    K_D(AudioOutput);
+    P_D(AudioOutput);
     d->init(category);
 }
 
 AudioOutput::AudioOutput(QObject *parent)
     : AbstractAudioOutput(*new AudioOutputPrivate, parent)
 {
-    K_D(AudioOutput);
+    P_D(AudioOutput);
     d->init(NoCategory);
 }
 
 void AudioOutputPrivate::init(Phonon::Category c)
 {
-    Q_Q(AudioOutput);
+    P_Q(AudioOutput);
 #ifndef PHONON_NO_DBUS
     adaptor = new AudioOutputAdaptor(q);
     static unsigned int number = 0;
@@ -134,7 +134,7 @@ void AudioOutputPrivate::createBackendObject()
 {
     if (m_backendObject)
         return;
-    Q_Q(AudioOutput);
+    P_Q(AudioOutput);
     m_backendObject = Factory::createAudioOutput(q);
     // (cg) Is it possible that PulseAudio initialisation means that the device here is not valid?
     // User reports seem to suggest this possibility but I can't see how :s.
@@ -147,13 +147,13 @@ void AudioOutputPrivate::createBackendObject()
 
 QString AudioOutput::name() const
 {
-    K_D(const AudioOutput);
+    P_D(const AudioOutput);
     return d->name;
 }
 
 void AudioOutput::setName(const QString &newName)
 {
-    K_D(AudioOutput);
+    P_D(AudioOutput);
     if (d->name == newName) {
         return;
     }
@@ -175,7 +175,7 @@ static const qreal VOLTAGE_TO_LOUDNESS_EXPONENT = qreal(1.0/LOUDNESS_TO_VOLTAGE_
 
 void AudioOutput::setVolume(qreal volume)
 {
-    K_D(AudioOutput);
+    P_D(AudioOutput);
     d->volume = volume;
     PulseSupport *pulse = PulseSupport::getInstance();
     if (k_ptr->backendObject()) {
@@ -199,7 +199,7 @@ void AudioOutput::setVolume(qreal volume)
 
 qreal AudioOutput::volume() const
 {
-    K_D(const AudioOutput);
+    P_D(const AudioOutput);
     if (d->muted || !d->m_backendObject || PulseSupport::getInstance()->isActive())
         return d->volume;
     return pow(INTERFACE_CALL(volume()), LOUDNESS_TO_VOLTAGE_EXPONENT);
@@ -212,7 +212,7 @@ static const qreal log10over20 = qreal(0.1151292546497022842); // ln(10) / 20
 
 qreal AudioOutput::volumeDecibel() const
 {
-    K_D(const AudioOutput);
+    P_D(const AudioOutput);
     if (d->muted || !d->m_backendObject || PulseSupport::getInstance()->isActive())
         return log(d->volume) / log10over20;
     return 0.67 * log(INTERFACE_CALL(volume())) / log10over20;
@@ -225,13 +225,13 @@ void AudioOutput::setVolumeDecibel(qreal newVolumeDecibel)
 
 bool AudioOutput::isMuted() const
 {
-    K_D(const AudioOutput);
+    P_D(const AudioOutput);
     return d->muted;
 }
 
 void AudioOutput::setMuted(bool mute)
 {
-    K_D(AudioOutput);
+    P_D(AudioOutput);
     if (d->muted != mute) {
         PulseSupport *pulse = PulseSupport::getInstance();
         if (mute) {
@@ -257,19 +257,19 @@ void AudioOutput::setMuted(bool mute)
 
 Category AudioOutput::category() const
 {
-    K_D(const AudioOutput);
+    P_D(const AudioOutput);
     return d->category;
 }
 
 AudioOutputDevice AudioOutput::outputDevice() const
 {
-    K_D(const AudioOutput);
+    P_D(const AudioOutput);
     return d->device;
 }
 
 bool AudioOutput::setOutputDevice(const AudioOutputDevice &newAudioOutputDevice)
 {
-    K_D(AudioOutput);
+    P_D(AudioOutput);
     if (!newAudioOutputDevice.isValid()) {
         d->outputDeviceOverridden = d->forceMove = false;
         const int newIndex = GlobalConfig().audioOutputDeviceFor(d->category);
@@ -300,7 +300,7 @@ bool AudioOutputPrivate::aboutToDeleteBackendObject()
 
 void AudioOutputPrivate::setupBackendObject()
 {
-    Q_Q(AudioOutput);
+    P_Q(AudioOutput);
     Q_ASSERT(m_backendObject);
     AbstractAudioOutputPrivate::setupBackendObject();
 
@@ -342,7 +342,7 @@ void AudioOutputPrivate::_k_volumeChanged(qreal newVolume)
 {
     volume = pow(newVolume, LOUDNESS_TO_VOLTAGE_EXPONENT);
     if (!muted) {
-        Q_Q(AudioOutput);
+        P_Q(AudioOutput);
         emit q->volumeChanged(volume);
     }
 }
@@ -350,7 +350,7 @@ void AudioOutputPrivate::_k_volumeChanged(qreal newVolume)
 void AudioOutputPrivate::_k_mutedChanged(bool newMuted)
 {
     muted = newMuted;
-    Q_Q(AudioOutput);
+    P_Q(AudioOutput);
     emit q->mutedChanged(newMuted);
 }
 
@@ -361,7 +361,7 @@ void AudioOutputPrivate::_k_revertFallback()
     }
     device = AudioOutputDevice::fromIndex(deviceBeforeFallback);
     callSetOutputDevice(this, device);
-    Q_Q(AudioOutput);
+    P_Q(AudioOutput);
     emit q->outputDeviceChanged(device);
 #ifndef PHONON_NO_DBUS
     emit adaptor->outputDeviceIndexChanged(device.index());
@@ -473,7 +473,7 @@ static struct
 
 void AudioOutputPrivate::handleAutomaticDeviceChange(const AudioOutputDevice &device2, DeviceChangeType type)
 {
-    Q_Q(AudioOutput);
+    P_Q(AudioOutput);
     deviceBeforeFallback = device.index();
     device = device2;
     emit q->outputDeviceChanged(device2);
