@@ -6,7 +6,7 @@
     License as published by the Free Software Foundation; either
     version 2.1 of the License, or (at your option) version 3, or any
     later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), Nokia Corporation 
+    successor approved by the membership of KDE e.V.), Nokia Corporation
     (or its successors, if any) and the KDE Free Qt Foundation, which shall
     act as a proxy defined in Section 6 of version 3 of the license.
 
@@ -15,7 +15,7 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     Lesser General Public License for more details.
 
-    You should have received a copy of the GNU Lesser General Public 
+    You should have received a copy of the GNU Lesser General Public
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 
 */
@@ -207,7 +207,7 @@ static QList<int> sortDevicesByCategoryPriority(const GlobalConfig *config, cons
 
 bool GlobalConfig::hideAdvancedDevices() const
 {
-    K_D(const GlobalConfig);
+    P_D(const GlobalConfig);
     //The devices need to be stored independently for every backend
     const QSettingsGroup generalGroup(&d->config, QLatin1String("General"));
     return generalGroup.value(QLatin1String("HideAdvancedDevices"), true);
@@ -215,7 +215,7 @@ bool GlobalConfig::hideAdvancedDevices() const
 
 void GlobalConfig::setHideAdvancedDevices(bool hide)
 {
-    K_D(GlobalConfig);
+    P_D(GlobalConfig);
     QSettingsGroup generalGroup(&d->config, QLatin1String("General"));
     generalGroup.setValue(QLatin1String("HideAdvancedDevices"), hide);
 }
@@ -398,7 +398,7 @@ void GlobalConfig::setAudioOutputDeviceListFor(Category category, QList<int> ord
     }
 
 #ifndef QT_NO_PHONON_SETTINGSGROUP
-    K_D(GlobalConfig);
+    P_D(GlobalConfig);
     QSettingsGroup backendConfig(&d->config, QLatin1String("AudioOutputDevice")); // + Factory::identifier());
 
     order = reindexList(this, AudioOutputDeviceType, category, order);
@@ -414,7 +414,7 @@ void GlobalConfig::setAudioOutputDeviceListFor(Category category, QList<int> ord
 
 QList<int> GlobalConfig::audioOutputDeviceListFor(Category category, int override) const
 {
-    K_D(const GlobalConfig);
+    P_D(const GlobalConfig);
 
 #ifndef QT_NO_PHONON_SETTINGSGROUP
     const bool hide = ((override & AdvancedDevicesFromSettings)
@@ -508,7 +508,7 @@ void GlobalConfig::setAudioCaptureDeviceListFor(CaptureCategory category, QList<
     }
 
 #ifndef QT_NO_PHONON_SETTINGSGROUP
-    K_D(GlobalConfig);
+    P_D(GlobalConfig);
     QSettingsGroup backendConfig(&d->config, QLatin1String("AudioCaptureDevice")); // + Factory::identifier());
 
     order = reindexList(this, AudioCaptureDeviceType, category, order);
@@ -524,7 +524,7 @@ void GlobalConfig::setAudioCaptureDeviceListFor(CaptureCategory category, QList<
 
 QList<int> GlobalConfig::audioCaptureDeviceListFor(CaptureCategory category, int override) const
 {
-    K_D(const GlobalConfig);
+    P_D(const GlobalConfig);
 
 #ifndef QT_NO_PHONON_SETTINGSGROUP
     const bool hide = ((override & AdvancedDevicesFromSettings)
@@ -632,7 +632,7 @@ int GlobalConfig::audioCaptureDeviceFor(Category category, int override) const
 void GlobalConfig::setVideoCaptureDeviceListFor(CaptureCategory category, QList<int> order)
 {
 #ifndef QT_NO_PHONON_SETTINGSGROUP
-    K_D(GlobalConfig);
+    P_D(GlobalConfig);
     QSettingsGroup backendConfig(&d->config, QLatin1String("VideoCaptureDevice")); // + Factory::identifier());
 
     order = reindexList(this, VideoCaptureDeviceType, category, order);
@@ -648,7 +648,7 @@ void GlobalConfig::setVideoCaptureDeviceListFor(CaptureCategory category, QList<
 
 QList<int> GlobalConfig::videoCaptureDeviceListFor(CaptureCategory category, int override) const
 {
-    K_D(const GlobalConfig);
+    P_D(const GlobalConfig);
 
 #ifndef QT_NO_PHONON_SETTINGSGROUP
     const bool hide = ((override & AdvancedDevicesFromSettings)
